<?php
/*
Plugin Name: tigaman webdesign - Social Sharing Buttons with Font Awesome Icons
Plugin URI: https://www.tigaman.com
Description: The plugin is allows users to easily add social sharing buttons to their single post content. The preferred social networks are: Facebook, Twitter, Pinterest, LinkedIn, Reddit, Tumblr, Messenger, Viber, WhatsApp and share in email.
Version: 1.0
Author: tigaman
Author URI: https://www.tigaman.hu
License: GPL2
*/

function add_social_sharing_buttons($content) {
  if (is_singular('post')) {
    $social_icons = array(
      'facebook' => array(
        'icon' => 'fa fa-facebook',
        'name' => 'facebook'
      ),
      'twitter' => array(
        'icon' => 'fa fa-twitter',
        'name' => 'twitter'
      ),
      'pinterest' => array(
        'icon' => 'fa fa-pinterest',
        'name' => 'pinterest'
      ),
      'linkedin' => array(
        'icon' => 'fa fa-linkedin',
        'name' => 'linkedin'
      ),
      'reddit' => array(
        'icon' => 'fa fa-reddit',
        'name' => 'reddit'
      ),
      'tumblr' => array(
        'icon' => 'fa fa-tumblr',
        'name' => 'tumblr'
      ),
      'messenger' => array(
        'icon' => 'fa fa-facebook-messenger',
        'name' => 'messenger'
      ),
      'viber' => array(
        'icon' => 'fa fa-viber',
        'name' => 'viber'
      ),
      'whatsapp' => array(
        'icon' => 'fa fa-whatsapp',
        'name' => 'whatsapp'
      ),
      'email' => array(
        'icon' => 'fa fa-envelope',
        'name' => 'envelope'
      )
    );

    $enabled_networks = get_option('social_sharing_networks', array_keys($social_icons));
    $selected_css = get_option('social_sharing_css', 'style.css');
    $buttons_position = get_option('social_sharing_position', 'after');

    $buttons = '';

    foreach ($social_icons as $network => $data) {
      if (in_array($network, $enabled_networks)) {
        $url = '';
        switch ($network) {
          case 'facebook':
            $url = 'https://www.facebook.com/sharer/sharer.php?u=' . urlencode(get_permalink()) . '&t=' . urlencode(get_the_title());
            break;
          case 'twitter':
           $url = 'https://twitter.com/intent/tweet?text=' . urlencode(get_the_title()) . '&url=' . urlencode(get_permalink());
            break;
          case 'pinterest':
            $url = 'https://pinterest.com/pin/create/button/?url=' . urlencode(get_permalink()) . '&media=' . urlencode(get_the_post_thumbnail_url(get_the_ID(), 'medium')) . '&description=' . urlencode(get_the_title()) ;
            break;
          case 'linkedin':
            $url = 'https://www.linkedin.com/shareArticle?mini=true&url=' . urlencode(get_permalink());
            break;
          case 'reddit':
            $url = 'https://reddit.com/submit?url=' . urlencode(get_permalink()) . '&title=' . urlencode(get_the_title());
            break;
          case 'tumblr':
            $url = 'https://www.tumblr.com/share/link?url=' . urlencode(get_permalink());
            break;
          case 'messenger':
            $url = 'fb-messenger://share/?link=' . urlencode(get_permalink());
            break;
          case 'viber':
            $url = 'viber://forward?text=' . urlencode(get_permalink());
            break;
          case 'whatsapp':
            $url = 'https://api.whatsapp.com/send?text=' . urlencode(get_permalink());
            break;
          case 'email':
            $url = 'mailto:?subject=' . urlencode(get_the_title()) . '&body=' . urlencode(get_permalink());
            break;
        }

        $buttons .= '<a href="' .$url.'" target="_blank" class="social-sharing-button ' . esc_html($data['name']) . '"><i class="' . esc_attr($data['icon']) . '"></i></a>';
      }
    }

    $social_buttons_html = '<div class="social-sharing-buttons">' . $buttons . '</div>';

    if ($buttons_position === 'before') {
      $content = $social_buttons_html . $content;
    } else {
      $content .= $social_buttons_html;
    }
  }

  return $content;
}

add_filter('the_content', 'add_social_sharing_buttons');

function social_sharing_settings_page() {
  $social_icons = array(
    'facebook' => 'Facebook',
    'twitter' => 'Twitter',
    'pinterest' => 'Pinterest',
    'linkedin' => 'LinkedIn',
    'reddit' => 'Reddit',
    'tumblr' => 'Tumblr',
    'messenger' => 'Messenger',
    'viber' => 'Viber',
    'whatsapp' => 'WhatsApp',
    'email' => 'Email'
  );

  $enabled_networks = get_option('social_sharing_networks', array_keys($social_icons));
  $selected_css = get_option('social_sharing_css', 'style.css');
  $buttons_position = get_option('social_sharing_position', 'after');

  if (isset($_POST['submit'])) {
    $enabled_networks = isset($_POST['networks']) ? array_map('sanitize_text_field', $_POST['networks']) : array();
    $selected_css = isset($_POST['css']) ? sanitize_text_field($_POST['css']) : 'style.css';
    $buttons_position = isset($_POST['position']) ? sanitize_text_field($_POST['position']) : 'after';

    update_option('social_sharing_networks', $enabled_networks);
    update_option('social_sharing_css', $selected_css);
    update_option('social_sharing_position', $buttons_position);
    echo '<script>window.location.reload();</script>';
  }



  ?>
  <div class="wrap">

    <h1>Social Sharing Buttons Settings</h1>
<?php 

	
	;?>
     <form method="post" action="">
      <div class="option-grid">
        <?php foreach ($social_icons as $network => $name) { ?>
          <div class="option">
            <input type="checkbox" id="<?php echo esc_attr($network); ?>" name="networks[]" value="<?php echo esc_attr($network); ?>" <?php checked(in_array($network, $enabled_networks)); ?>><br />
        <!--    <label for="<?php echo esc_attr($network); ?>"><?php echo esc_html($name); ?></label> -->
            <div class="social-sharing-buttons">
              <a href="#" class="social-sharing-button <?php echo esc_attr($network); ?>"><i class="fa fa-<?php echo esc_attr($network); ?>"></i></a>
            </div>
          </div>
        <?php } ?>
      </div>

      <div class="option-group">
        <h3>Button style</h3>
        <select name="css">

          
<option value="style.css" <?php selected($selected_css, 'style.css'); ?>>small icons</option>
<option value="style2.css" <?php selected($selected_css, 'style2.css'); ?>>small rounded icons</option>
<option value="style3.css" <?php selected($selected_css, 'style3.css'); ?>>big icons</option>
<option value="style4.css" <?php selected($selected_css, 'style4.css'); ?>>big rounded icons</option>
<option value="style5.css" <?php selected($selected_css, 'style5.css'); ?>>micro icons</option>
<option value="style6.css" <?php selected($selected_css, 'style6.css'); ?>>micro rounded icons</option>
<option value="style7.css" <?php selected($selected_css, 'style7.css'); ?>>minimal icons</option>
<option value="style8.css" <?php selected($selected_css, 'style8.css'); ?>>minimal rounded icons</option>         
          
        </select>
      </div>

      <div class="option-group">
        <h3>Buttons Position</h3>
        <div class="option">
          <input type="radio" id="position_before" name="position" value="before" <?php checked($buttons_position, 'before'); ?>>
          <label for="position_before">Before the content</label>

          <input type="radio" id="position_after" name="position" value="after" <?php checked($buttons_position, 'after'); ?>>
          <label for="position_after">After the content</label>
        </div>
      </div>

      <div class="submit">
        <input type="submit" name="submit" class="button-primary" value="Save Changes">
      </div>
    </form>
 <hr />
        <h1 align="center">More great freebies</h1>
        <style type="text/css">
            #tigamandotcom {
                width: 100%;
                height: 800px;
                overflow-x: hidden;
            }


            .clear {
                clear: both;
            }

            #wpfooter {
                display: none;
            }
        </style>
        <div id="tigamandotcom">
            <embed type="text/html" src="https://www.tigaman.com/tigaman-webdesign-wordpress-plugins/" style="width: 100%; height: 800px;"></embed>
        </div>
        <div class="clear"></div>


  </div>
<style type="text/css">
.option-grid {
  display: grid;
  -ms-grid-columns: minmax(63px, 1fr) [auto-fit];
  grid-template-columns: repeat(auto-fit, minmax(60px, 1fr));
  grid-gap: 20px;
}

.option {
text-align: center;

}

.option label {

}

.option-group {

}
.social-sharing-buttons {
margin:5px 0 0 0; 
}

.submit {
  margin-top: 20px;
}
</style>
  <?php
}

function social_sharing_add_settings_page() {
  add_options_page('Social Sharing Buttons Settings', 'Social Sharing Buttons', 'manage_options', 'social-sharing-buttons', 'social_sharing_settings_page');
}

add_action('admin_menu', 'social_sharing_add_settings_page');

// Enqueue Font Awesome CSS
function twd_sssb_enqueue_font_awesome() {
  wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css');
}
add_action('wp_enqueue_scripts', 'twd_sssb_enqueue_font_awesome');
add_action('admin_enqueue_scripts', 'twd_sssb_enqueue_font_awesome');

// Enqueue selected CSS file
function social_sharing_enqueue_css() {
  $selected_css = get_option('social_sharing_css', 'style.css');
  wp_enqueue_style('social-sharing-css', plugins_url($selected_css, __FILE__));
}
add_action('wp_enqueue_scripts', 'social_sharing_enqueue_css');
add_action('admin_enqueue_scripts', 'social_sharing_enqueue_css');

// Function to add meta tags to the head section
function add_social_sharing_meta_tags() {
  if (is_singular('post')) {
    $enabled_networks = get_option('social_sharing_networks', array());

    if (in_array('facebook', $enabled_networks)) {
      echo '<!-- developed by tigaman webdesing - tigaman.com  trckr: twd_ssb_2023 -->' . "\n";
      echo '<meta property="og:title" content="' . get_the_title() . '" />' . "\n";
      echo '<meta property="og:description" content="' . get_the_excerpt() . '" />' . "\n";
      echo '<meta property="og:url" content="' . get_permalink() . '" />' . "\n";
      echo '<meta property="og:image" content="' . get_the_post_thumbnail_url(get_the_ID(), 'medium') . '" />' . "\n";
    }

    if (in_array('twitter', $enabled_networks)) {
      echo '<meta name="twitter:card" content="summary_large_image" />' . "\n";
      echo '<meta name="twitter:title" content="' . get_the_title() . '" />' . "\n";
      echo '<meta name="twitter:description" content="' . get_the_excerpt() . '" />' . "\n";
      echo '<meta name="twitter:image" content="' . get_the_post_thumbnail_url(get_the_ID(), 'medium') . '" />' . "\n";
      echo '<meta name="twitter:url" content="' . get_permalink() . '" />' . "\n";
      echo '<meta name="twitter:domain" content="' . get_bloginfo('url') . '" />' . "\n";
    }
    if (in_array('pinterest', $enabled_networks)) {
      echo '<meta name="pinterest:description" content="' . get_the_excerpt() . '" />' . "\n";
      echo '<meta name="pinterest:image" content="' . get_the_post_thumbnail_url(get_the_ID(), 'medium') . '" />' . "\n";
    }
    if (in_array('linkedin', $enabled_networks)) {
      echo '<meta property="linkedin:title" content="' . get_the_title() . '" />' . "\n";
      echo '<meta property="linkedin:description" content="' . get_the_excerpt() . '" />' . "\n";
      echo '<meta property="linkedin:url" content="' . get_permalink() . '" />' . "\n";
      echo '<meta property="linkedin:image" content="' . get_the_post_thumbnail_url(get_the_ID(), 'medium') . '" />' . "\n";
      echo '<meta property="linkedin:site" content="' . get_bloginfo('name') . '" />' . "\n";
    }
    if (in_array('reddit', $enabled_networks)) {
      echo '<meta property="reddit:title" content="' . get_the_title() . '" />' . "\n";
      echo '<meta property="reddit:url" content="' . get_permalink() . '" />' . "\n";
    }

    // Add meta tags for other social networks if needed
  }
}

// Hook the function to the wp_head action
add_action('wp_head', 'add_social_sharing_meta_tags');
add_filter( 'excerpt_length', function($length) {
    return 20;
}, PHP_INT_MAX );
function trim_excerpt($text){
    return rtrim(str_replace('[&hellip', '', $text), '[...]');
}
add_filter('get_the_excerpt', 'trim_excerpt');

// Add settings link to plugin action links
function twd_social_sharing_add_settings_link($links) {
    $settings_link = '<a href="' . admin_url('options-general.php?page=social-sharing-buttons') . '">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'twd_social_sharing_add_settings_link');

?>